Struct google_accessapproval1::api::ApproveApprovalRequestMessage [−][src]
Request to approve an ApprovalRequest.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- approval requests approve folders (request)
- approval requests approve organizations (request)
- approval requests approve projects (request)
Fields
expire_time: Option<String>The expiration time of this approval.