pub struct AugmentedInfo {
pub command: Option<String>,
}Expand description
This field contains the augmented information of the request. Requires augmented administrative access to be enabled.
This type is not used in any activity, and only used as part of another schema.
Fields
command: Option<String>For command-line tools, the full command-line exactly as entered by the actor without adding any additional characters (such as quotation marks).